summaryrefslogtreecommitdiff
path: root/chromium/third_party/blink/tools/blinkpy/web_tests/models
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/blink/tools/blinkpy/web_tests/models')
-rw-r--r--chromium/third_party/blink/tools/blinkpy/web_tests/models/test_expectations.py6
-rw-r--r--chromium/third_party/blink/tools/blinkpy/web_tests/models/test_expectations_unittest.py8
-rw-r--r--chromium/third_party/blink/tools/blinkpy/web_tests/models/test_run_results.py4
3 files changed, 9 insertions, 9 deletions
diff --git a/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_expectations.py b/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_expectations.py
index c38853af5c0..cd64e3e4e07 100644
--- a/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_expectations.py
+++ b/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_expectations.py
@@ -26,7 +26,7 @@
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-"""A helper class for reading in and dealing with tests expectations for layout tests."""
+"""A helper class for reading in and dealing with tests expectations for web tests."""
from collections import defaultdict
@@ -880,7 +880,7 @@ class TestExpectationsModel(object):
class TestExpectations(object):
"""Test expectations consist of lines with specifications of what
- to expect from layout test cases. The test cases can be directories
+ to expect from web test cases. The test cases can be directories
in which case the expectations apply to all test cases in that
directory and any subdirectory. The format is along the lines of:
@@ -1017,7 +1017,7 @@ class TestExpectations(object):
return set(suffixes)
@staticmethod
- # test_result is an instance of blinkpy.common.net.layout_test_results.LayoutTestResult
+ # test_result is an instance of blinkpy.common.net.web_test_results.WebTestResult
def suffixes_for_test_result(test_result):
suffixes = set()
actual_results = test_result.actual_results()
diff --git a/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_expectations_unittest.py b/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_expectations_unittest.py
index a81fbaa7f01..8331deaa53f 100644
--- a/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_expectations_unittest.py
+++ b/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_expectations_unittest.py
@@ -168,8 +168,8 @@ class MiscTests(Base):
def test_parse_warning(self):
try:
filesystem = self._port.host.filesystem
- filesystem.write_text_file(filesystem.join(self._port.layout_tests_dir(), 'disabled-test.html-disabled'), 'content')
- filesystem.write_text_file(filesystem.join(self._port.layout_tests_dir(), 'test-to-rebaseline.html'), 'content')
+ filesystem.write_text_file(filesystem.join(self._port.web_tests_dir(), 'disabled-test.html-disabled'), 'content')
+ filesystem.write_text_file(filesystem.join(self._port.web_tests_dir(), 'test-to-rebaseline.html'), 'content')
self.parse_exp('Bug(user) [ FOO ] failures/expected/text.html [ Failure ]\n'
'Bug(user) non-existent-test.html [ Failure ]\n'
'Bug(user) disabled-test.html-disabled [ Failure ]\n',
@@ -242,7 +242,7 @@ Bug(test) failures/expected/timeout.html [ Timeout ]
self.assert_exp('failures/expected/text.html', FAIL)
self.assertNotIn(
self._port.host.filesystem.join(
- self._port.layout_tests_dir(),
+ self._port.web_tests_dir(),
'failures/expected/text.html'),
self._exp.get_tests_with_result_type(SKIP))
@@ -284,7 +284,7 @@ class SkippedTests(Base):
options=optparse.Values({'ignore_tests': ignore_tests}))
port.host.filesystem.write_text_file(
port.host.filesystem.join(
- port.layout_tests_dir(), 'failures/expected/text.html'),
+ port.web_tests_dir(), 'failures/expected/text.html'),
'foo')
expectations_dict = OrderedDict()
expectations_dict['expectations'] = expectations
diff --git a/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_run_results.py b/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_run_results.py
index fff5ba524ec..9ad7bcc2f4b 100644
--- a/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_run_results.py
+++ b/chromium/third_party/blink/tools/blinkpy/web_tests/models/test_run_results.py
@@ -61,7 +61,7 @@ class TestRunResults(object):
self.unexpected_failures = 0
self.unexpected_timeouts = 0
# The wall clock time spent running the tests (layout_test_runner.run()).
self.run_time = 0
# Map of test name to the *last* result for the test.
@@ -365,7 +365,7 @@ def summarize_results(port_obj, expectations, initial_results,
# Does results.html have enough information to compute this itself? (by
# checking total number of results vs. total number of tests?)
results['interrupted'] = initial_results.interrupted
- results['layout_tests_dir'] = port_obj.layout_tests_dir()
+ results['layout_tests_dir'] = port_obj.web_tests_dir()
results['seconds_since_epoch'] = int(time.time())
results['build_number'] = port_obj.get_option('build_number')
results['builder_name'] = port_obj.get_option('builder_name')
@@ -61,7 +61,7 @@ class TestRunResults(object):
self.unexpected_failures = 0
self.unexpected_timeouts = 0
- # The wall clock time spent running the tests (layout_test_runner.run()).
+ # The wall clock time spent running the tests (web_test_runner.run()).
self.run_time = 0
# Map of test name to the *last* result for the test.